import{k as g,i as o,t as a,u as p,M as h,c as i,h as d,g as f,Q as m,R as y,S as x,Y as v}from"./index.c86eb251.js";import{h as C}from"./render.da949024.js";var _=g({name:"QPage",props:{padding:Boolean,styleFn:Function},setup(s,{slots:r}){const{proxy:{$q:t}}=f(),e=o(p,a);if(e===a)return console.error("QPage needs to be a deep child of QLayout"),a;if(o(h,a)===a)return console.error("QPage needs to be child of QPageContainer"),a;const c=i(()=>{const n=(e.header.space===!0?e.header.size:0)+(e.footer.space===!0?e.footer.size:0);if(typeof s.styleFn=="function"){const u=e.isContainer.value===!0?e.containerHeight.value:t.screen.height;return s.styleFn(n,u)}return{minHeight:e.isContainer.value===!0?e.containerHeight.value-n+"px":t.screen.height===0?n!==0?`calc(100vh - ${n}px)`:"100vh":t.screen.height-n+"px"}}),l=i(()=>`q-page${s.padding===!0?" q-layout-padding":""}`);return()=>d("main",{class:l.value,style:c.value},C(r.default))}}),Q="/assets/quasar-logo-vertical.55e9c854.svg";const q=Object.assign({name:"IndexPage"},{__name:"IndexPage",setup(s){return(r,t)=>(m(),y(_,{class:"flex flex-center"},{default:x(()=>t[0]||(t[0]=[v("img",{alt:"Quasar logo",src:Q,style:{width:"200px",height:"200px"}},null,-1)])),_:1}))}});export{q as default};
