import{h as c,K as f}from"./index.c86eb251.js";function h(n,r){return n!==void 0&&n()||r}function a(n,r){if(n!==void 0){const i=n();if(i!=null)return i.slice()}return r}function d(n,r){return n!==void 0?r.concat(n()):r}function s(n,r,i,o,t,u){r.key=o+t;const e=c(n,r,i);return t===!0?f(e,u()):e}export{a,s as b,d as c,h};
