import{d as o}from"./QBtn.eb240f76.js";import{Q as s,Z as r,Y as t,f as l}from"./index.c86eb251.js";import"./render.da949024.js";const n={class:"fullscreen bg-blue text-white text-center q-pa-md flex flex-center"},p=Object.assign({name:"ErrorNotFound"},{__name:"ErrorNotFound",setup(a){return(i,e)=>(s(),r("div",n,[t("div",null,[e[0]||(e[0]=t("div",{style:{"font-size":"30vh"}}," 404 ",-1)),e[1]||(e[1]=t("div",{class:"text-h2",style:{opacity:".4"}}," Oops. Nothing here... ",-1)),l(o,{class:"q-mt-xl",color:"white","text-color":"blue",unelevated:"",to:"/",label:"Go Home","no-caps":""})])]))}});export{p as default};
